<?php
/**
 * @file
 * Block Classes Utility
 */

/**
 * OM Tools Block Utility Settings
 *
 */
function om_block_tools(&$form, $block_classes) {
  drupal_add_js(drupal_get_path('module', 'om_tools') . '/tools/block/js/block.js', 'file');
  
  // get new blocks
  $block_classes = om_block_classes_get($block_classes, FALSE);  
  
  // reset block classes
  if (isset($block_classes['block_classes_reset']) && ($block_classes['block_classes_reset'] == 1)) {
    $block_classes['block_classes_reset'] = 0;
    $block_classes = om_block_classes_get($block_classes, TRUE);
  }  
  
  // Block Tool   
  $form['om_block_tools'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_block_tools']['block_classes'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block Classes'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['om_block_tools']['block_classes']['block_classes_switch'] = array(
    '#type' => 'checkbox',
    '#title' =>  t('Add custom block classes'),
    '#default_value' => isset($block_classes['block_classes_switch']) ? $block_classes['block_classes_switch']: 0,
  );  
  $form['om_block_tools']['block_classes']['block_classes_settings'] = array(
    '#type' => 'fieldset',
    '#attributes' => array( 'id' => 'om-group-block-classes-settings'),
    '#title' => t('Block Classes Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );  
  $excluded = array('block_classes_switch', 'block_classes_reset');
  foreach ($block_classes as $name => $val) {
    if (!in_array($name, $excluded)) {
      $module = explode('_', $name);
      $delta = !empty($module[4]) ? $module[3] . '_' . $module[4]: $module[3];
      $form['om_block_tools']['block_classes']['block_classes_settings']['block_classes_' . $module[2] . '_' . $delta] = array(
        '#type' => 'textfield',
        '#title' => t('ID: ' . 'block-' . $module[2] . '-' . $delta . ' <a href="' . base_path() . 'admin/structure/block/manage/' . $module[2] . '/' . $module[3] . '/configure?destination=admin/config/system/om-tools">Edit</a>'),
        '#default_value' => $val,
      );  
    }
  }
  $form['om_block_tools']['block_classes']['block_classes_reset'] = array(
    '#type' => 'checkbox',
    '#title' => t('Reset to default values.'),      
    '#default_value' => isset($block_classes['block_classes_reset']) ? $block_classes['block_classes_reset']: 0,
  );                   
  return $form;  
}


/**
 * Override or insert om variables into the templates.
 */
function om_block_preprocess_block(&$vars) {
  $block = $vars['block'];
  $block_classes = $vars['om_block_tools_values'];  
  //dsm($block);
  if (isset($block_classes['block_classes_switch']) && ($block_classes['block_classes_switch'] == 1)) {
    $vars['classes_array'][] = $block_classes['block_classes_' . $block->module . '_' . $block->delta];
  }
}
 

/**
 * default blocks classes
 *
 */
function om_block_classes_get($block_classes = array(), $reset = FALSE) {
  $theme_default = variable_get('theme_default', 'garland');
  
  // boxes table is for custom blocks
  $custom_sql = "SELECT bid, info FROM {block_custom} ORDER BY info ASC";
  
  $custom_result = db_query($custom_sql);

  $custom_classes = array();
  while ($custom_record = $custom_result->fetchObject()) {
    $custom_classes[$custom_record->bid] = om_tools_class_safe($custom_record->info);
  }

  // default, module generated blocks
  $block_sql = "SELECT module, delta FROM {block} WHERE theme = :theme_default ORDER BY module, delta ASC";
  
  $block_result = db_query($block_sql, array('theme_default' => $theme_default));

  $current_blocks = array();
  
  while ($block_record = $block_result->fetchObject()) {
    // new blocks
    if (!isset($block_classes['block_classes_' . $block_record->module . '_' . $block_record->delta]) || ($reset == TRUE)) { 
      if ($block_record->module == 'block') {
        $classes = 'block-' . $box_classes[$block_record->delta];
      }
      else {
        $classes = 'block-' . $block_record->module . '-' . $block_record->delta;
      }
    }
    // old blocks
    else { 
      $classes = $block_classes['block_classes_' . $block_record->module . '_' . $block_record->delta];
    }
    // this will ignore non-existing blocks
    $current_blocks['block_classes_' . $block_record->module . '_' . $block_record->delta] = $classes;  
  }
  $current_blocks['block_classes_switch'] = isset($block_classes['block_classes_switch']) ? $block_classes['block_classes_switch']: 0;
  
  ksort($current_blocks);

  return $current_blocks;
} 



